# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RouterVpcAssociationArgs', 'RouterVpcAssociation']

@pulumi.input_type
class RouterVpcAssociationArgs:
    def __init__(__self__, *,
                 association_region_id: pulumi.Input[str],
                 ecr_id: pulumi.Input[str],
                 vpc_id: pulumi.Input[str],
                 allowed_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 vpc_owner_id: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a RouterVpcAssociation resource.
        :param pulumi.Input[str] association_region_id: The region to which the VPC or TR belongs.
        :param pulumi.Input[str] ecr_id: The ID of the leased line gateway instance.
        :param pulumi.Input[str] vpc_id: The ID of the VPC instance.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_prefixes: List of allowed route prefixes.
        :param pulumi.Input[int] vpc_owner_id: The ID of the Alibaba Cloud account to which the VPC belongs.
        """
        pulumi.set(__self__, "association_region_id", association_region_id)
        pulumi.set(__self__, "ecr_id", ecr_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if allowed_prefixes is not None:
            pulumi.set(__self__, "allowed_prefixes", allowed_prefixes)
        if vpc_owner_id is not None:
            pulumi.set(__self__, "vpc_owner_id", vpc_owner_id)

    @property
    @pulumi.getter(name="associationRegionId")
    def association_region_id(self) -> pulumi.Input[str]:
        """
        The region to which the VPC or TR belongs.
        """
        return pulumi.get(self, "association_region_id")

    @association_region_id.setter
    def association_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "association_region_id", value)

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> pulumi.Input[str]:
        """
        The ID of the leased line gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @ecr_id.setter
    def ecr_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "ecr_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The ID of the VPC instance.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="allowedPrefixes")
    def allowed_prefixes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of allowed route prefixes.
        """
        return pulumi.get(self, "allowed_prefixes")

    @allowed_prefixes.setter
    def allowed_prefixes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_prefixes", value)

    @property
    @pulumi.getter(name="vpcOwnerId")
    def vpc_owner_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the Alibaba Cloud account to which the VPC belongs.
        """
        return pulumi.get(self, "vpc_owner_id")

    @vpc_owner_id.setter
    def vpc_owner_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "vpc_owner_id", value)


@pulumi.input_type
class _RouterVpcAssociationState:
    def __init__(__self__, *,
                 allowed_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 association_id: Optional[pulumi.Input[str]] = None,
                 association_region_id: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 ecr_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_owner_id: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering RouterVpcAssociation resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_prefixes: List of allowed route prefixes.
        :param pulumi.Input[str] association_id: The first ID of the resource.
        :param pulumi.Input[str] association_region_id: The region to which the VPC or TR belongs.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] ecr_id: The ID of the leased line gateway instance.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[str] vpc_id: The ID of the VPC instance.
        :param pulumi.Input[int] vpc_owner_id: The ID of the Alibaba Cloud account to which the VPC belongs.
        """
        if allowed_prefixes is not None:
            pulumi.set(__self__, "allowed_prefixes", allowed_prefixes)
        if association_id is not None:
            pulumi.set(__self__, "association_id", association_id)
        if association_region_id is not None:
            pulumi.set(__self__, "association_region_id", association_region_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if ecr_id is not None:
            pulumi.set(__self__, "ecr_id", ecr_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_owner_id is not None:
            pulumi.set(__self__, "vpc_owner_id", vpc_owner_id)

    @property
    @pulumi.getter(name="allowedPrefixes")
    def allowed_prefixes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of allowed route prefixes.
        """
        return pulumi.get(self, "allowed_prefixes")

    @allowed_prefixes.setter
    def allowed_prefixes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_prefixes", value)

    @property
    @pulumi.getter(name="associationId")
    def association_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "association_id")

    @association_id.setter
    def association_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "association_id", value)

    @property
    @pulumi.getter(name="associationRegionId")
    def association_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The region to which the VPC or TR belongs.
        """
        return pulumi.get(self, "association_region_id")

    @association_region_id.setter
    def association_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "association_region_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the leased line gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @ecr_id.setter
    def ecr_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ecr_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VPC instance.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcOwnerId")
    def vpc_owner_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the Alibaba Cloud account to which the VPC belongs.
        """
        return pulumi.get(self, "vpc_owner_id")

    @vpc_owner_id.setter
    def vpc_owner_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "vpc_owner_id", value)


class RouterVpcAssociation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 association_region_id: Optional[pulumi.Input[str]] = None,
                 ecr_id: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_owner_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a Express Connect Router Express Connect Router Vpc Association resource. Bind relationship object between leased line gateway and VPC.

        For information about Express Connect Router Express Connect Router Vpc Association and how to use it, see [What is Express Connect Router Vpc Association](https://next.api.alibabacloud.com/api/ExpressConnectRouter/2023-09-01/CreateExpressConnectRouterAssociation).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default8q_at_d6 = alicloud.vpc.Network("default8qAtD6", cidr_block="172.16.0.0/16")
        default_m9_yx_gw = alicloud.expressconnect.RouterExpressConnectRouter("defaultM9YxGW", alibaba_side_asn=65533)
        current = alicloud.get_account()
        default = alicloud.expressconnect.RouterVpcAssociation("default",
            ecr_id=default_m9_yx_gw.id,
            allowed_prefixes=[
                "172.16.4.0/24",
                "172.16.3.0/24",
                "172.16.2.0/24",
                "172.16.1.0/24",
            ],
            vpc_owner_id=current.id,
            association_region_id="cn-hangzhou",
            vpc_id=default8q_at_d6.id)
        ```

        ## Import

        Express Connect Router Express Connect Router Vpc Association can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/routerVpcAssociation:RouterVpcAssociation example <ecr_id>:<association_id>:<vpc_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_prefixes: List of allowed route prefixes.
        :param pulumi.Input[str] association_region_id: The region to which the VPC or TR belongs.
        :param pulumi.Input[str] ecr_id: The ID of the leased line gateway instance.
        :param pulumi.Input[str] vpc_id: The ID of the VPC instance.
        :param pulumi.Input[int] vpc_owner_id: The ID of the Alibaba Cloud account to which the VPC belongs.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouterVpcAssociationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Router Express Connect Router Vpc Association resource. Bind relationship object between leased line gateway and VPC.

        For information about Express Connect Router Express Connect Router Vpc Association and how to use it, see [What is Express Connect Router Vpc Association](https://next.api.alibabacloud.com/api/ExpressConnectRouter/2023-09-01/CreateExpressConnectRouterAssociation).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default8q_at_d6 = alicloud.vpc.Network("default8qAtD6", cidr_block="172.16.0.0/16")
        default_m9_yx_gw = alicloud.expressconnect.RouterExpressConnectRouter("defaultM9YxGW", alibaba_side_asn=65533)
        current = alicloud.get_account()
        default = alicloud.expressconnect.RouterVpcAssociation("default",
            ecr_id=default_m9_yx_gw.id,
            allowed_prefixes=[
                "172.16.4.0/24",
                "172.16.3.0/24",
                "172.16.2.0/24",
                "172.16.1.0/24",
            ],
            vpc_owner_id=current.id,
            association_region_id="cn-hangzhou",
            vpc_id=default8q_at_d6.id)
        ```

        ## Import

        Express Connect Router Express Connect Router Vpc Association can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/routerVpcAssociation:RouterVpcAssociation example <ecr_id>:<association_id>:<vpc_id>
        ```

        :param str resource_name: The name of the resource.
        :param RouterVpcAssociationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouterVpcAssociationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 association_region_id: Optional[pulumi.Input[str]] = None,
                 ecr_id: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_owner_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouterVpcAssociationArgs.__new__(RouterVpcAssociationArgs)

            __props__.__dict__["allowed_prefixes"] = allowed_prefixes
            if association_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'association_region_id'")
            __props__.__dict__["association_region_id"] = association_region_id
            if ecr_id is None and not opts.urn:
                raise TypeError("Missing required property 'ecr_id'")
            __props__.__dict__["ecr_id"] = ecr_id
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["vpc_owner_id"] = vpc_owner_id
            __props__.__dict__["association_id"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(RouterVpcAssociation, __self__).__init__(
            'alicloud:expressconnect/routerVpcAssociation:RouterVpcAssociation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            association_id: Optional[pulumi.Input[str]] = None,
            association_region_id: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            ecr_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vpc_owner_id: Optional[pulumi.Input[int]] = None) -> 'RouterVpcAssociation':
        """
        Get an existing RouterVpcAssociation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_prefixes: List of allowed route prefixes.
        :param pulumi.Input[str] association_id: The first ID of the resource.
        :param pulumi.Input[str] association_region_id: The region to which the VPC or TR belongs.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] ecr_id: The ID of the leased line gateway instance.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[str] vpc_id: The ID of the VPC instance.
        :param pulumi.Input[int] vpc_owner_id: The ID of the Alibaba Cloud account to which the VPC belongs.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RouterVpcAssociationState.__new__(_RouterVpcAssociationState)

        __props__.__dict__["allowed_prefixes"] = allowed_prefixes
        __props__.__dict__["association_id"] = association_id
        __props__.__dict__["association_region_id"] = association_region_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["ecr_id"] = ecr_id
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpc_owner_id"] = vpc_owner_id
        return RouterVpcAssociation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowedPrefixes")
    def allowed_prefixes(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of allowed route prefixes.
        """
        return pulumi.get(self, "allowed_prefixes")

    @property
    @pulumi.getter(name="associationId")
    def association_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "association_id")

    @property
    @pulumi.getter(name="associationRegionId")
    def association_region_id(self) -> pulumi.Output[str]:
        """
        The region to which the VPC or TR belongs.
        """
        return pulumi.get(self, "association_region_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> pulumi.Output[str]:
        """
        The ID of the leased line gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The ID of the VPC instance.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcOwnerId")
    def vpc_owner_id(self) -> pulumi.Output[int]:
        """
        The ID of the Alibaba Cloud account to which the VPC belongs.
        """
        return pulumi.get(self, "vpc_owner_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetChildInstanceRouteEntryToAttachmentsResult',
    'AwaitableGetChildInstanceRouteEntryToAttachmentsResult',
    'get_child_instance_route_entry_to_attachments',
    'get_child_instance_route_entry_to_attachments_output',
]

@pulumi.output_type
class GetChildInstanceRouteEntryToAttachmentsResult:
    """
    A collection of values returned by getChildInstanceRouteEntryToAttachments.
    """
    def __init__(__self__, attachments=None, cen_id=None, child_instance_route_table_id=None, id=None, ids=None, output_file=None, service_type=None, transit_router_attachment_id=None):
        if attachments and not isinstance(attachments, list):
            raise TypeError("Expected argument 'attachments' to be a list")
        pulumi.set(__self__, "attachments", attachments)
        if cen_id and not isinstance(cen_id, str):
            raise TypeError("Expected argument 'cen_id' to be a str")
        pulumi.set(__self__, "cen_id", cen_id)
        if child_instance_route_table_id and not isinstance(child_instance_route_table_id, str):
            raise TypeError("Expected argument 'child_instance_route_table_id' to be a str")
        pulumi.set(__self__, "child_instance_route_table_id", child_instance_route_table_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if service_type and not isinstance(service_type, str):
            raise TypeError("Expected argument 'service_type' to be a str")
        pulumi.set(__self__, "service_type", service_type)
        if transit_router_attachment_id and not isinstance(transit_router_attachment_id, str):
            raise TypeError("Expected argument 'transit_router_attachment_id' to be a str")
        pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)

    @property
    @pulumi.getter
    def attachments(self) -> Sequence['outputs.GetChildInstanceRouteEntryToAttachmentsAttachmentResult']:
        """
        A list of Child Instance Route Entry To Attachment Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "attachments")

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[str]:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="childInstanceRouteTableId")
    def child_instance_route_table_id(self) -> str:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "child_instance_route_table_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        Limit search to a list of specific IDs.The value is formulated as `<cen_id>:<child_instance_route_table_id>:<transit_router_attachment_id>:<destination_cidr_block>`.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="serviceType")
    def service_type(self) -> Optional[str]:
        """
        ServiceType
        """
        return pulumi.get(self, "service_type")

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> str:
        """
        TransitRouterAttachmentId
        """
        return pulumi.get(self, "transit_router_attachment_id")


class AwaitableGetChildInstanceRouteEntryToAttachmentsResult(GetChildInstanceRouteEntryToAttachmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetChildInstanceRouteEntryToAttachmentsResult(
            attachments=self.attachments,
            cen_id=self.cen_id,
            child_instance_route_table_id=self.child_instance_route_table_id,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            service_type=self.service_type,
            transit_router_attachment_id=self.transit_router_attachment_id)


def get_child_instance_route_entry_to_attachments(cen_id: Optional[str] = None,
                                                  child_instance_route_table_id: Optional[str] = None,
                                                  ids: Optional[Sequence[str]] = None,
                                                  output_file: Optional[str] = None,
                                                  service_type: Optional[str] = None,
                                                  transit_router_attachment_id: Optional[str] = None,
                                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetChildInstanceRouteEntryToAttachmentsResult:
    """
    This data source provides Cen Child Instance Route Entry To Attachment available to the user.[What is Child Instance Route Entry To Attachment](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-createcenchildinstancerouteentrytoattachment)

    > **NOTE:** Available in 1.195.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_child_instance_route_entry_to_attachments(child_instance_route_table_id="vtb-t4nt0z5xxbti85c78nkzy",
        transit_router_attachment_id="tr-attach-f1fd1y50rql00emvej")
    pulumi.export("alicloudCenChildInstanceRouteEntryToAttachmentExampleId", default.attachments[0].id)
    ```


    :param str cen_id: The ID of the CEN instance.
    :param str child_instance_route_table_id: The first ID of the resource
    :param Sequence[str] ids: Limit search to a list of specific IDs.The value is formulated as `<cen_id>:<child_instance_route_table_id>:<transit_router_attachment_id>:<destination_cidr_block>`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str service_type: ServiceType
    :param str transit_router_attachment_id: TransitRouterAttachmentId
    """
    __args__ = dict()
    __args__['cenId'] = cen_id
    __args__['childInstanceRouteTableId'] = child_instance_route_table_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['serviceType'] = service_type
    __args__['transitRouterAttachmentId'] = transit_router_attachment_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getChildInstanceRouteEntryToAttachments:getChildInstanceRouteEntryToAttachments', __args__, opts=opts, typ=GetChildInstanceRouteEntryToAttachmentsResult).value

    return AwaitableGetChildInstanceRouteEntryToAttachmentsResult(
        attachments=pulumi.get(__ret__, 'attachments'),
        cen_id=pulumi.get(__ret__, 'cen_id'),
        child_instance_route_table_id=pulumi.get(__ret__, 'child_instance_route_table_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        service_type=pulumi.get(__ret__, 'service_type'),
        transit_router_attachment_id=pulumi.get(__ret__, 'transit_router_attachment_id'))
def get_child_instance_route_entry_to_attachments_output(cen_id: Optional[pulumi.Input[Optional[str]]] = None,
                                                         child_instance_route_table_id: Optional[pulumi.Input[str]] = None,
                                                         ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                                         output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                         service_type: Optional[pulumi.Input[Optional[str]]] = None,
                                                         transit_router_attachment_id: Optional[pulumi.Input[str]] = None,
                                                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetChildInstanceRouteEntryToAttachmentsResult]:
    """
    This data source provides Cen Child Instance Route Entry To Attachment available to the user.[What is Child Instance Route Entry To Attachment](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-createcenchildinstancerouteentrytoattachment)

    > **NOTE:** Available in 1.195.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_child_instance_route_entry_to_attachments(child_instance_route_table_id="vtb-t4nt0z5xxbti85c78nkzy",
        transit_router_attachment_id="tr-attach-f1fd1y50rql00emvej")
    pulumi.export("alicloudCenChildInstanceRouteEntryToAttachmentExampleId", default.attachments[0].id)
    ```


    :param str cen_id: The ID of the CEN instance.
    :param str child_instance_route_table_id: The first ID of the resource
    :param Sequence[str] ids: Limit search to a list of specific IDs.The value is formulated as `<cen_id>:<child_instance_route_table_id>:<transit_router_attachment_id>:<destination_cidr_block>`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str service_type: ServiceType
    :param str transit_router_attachment_id: TransitRouterAttachmentId
    """
    __args__ = dict()
    __args__['cenId'] = cen_id
    __args__['childInstanceRouteTableId'] = child_instance_route_table_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['serviceType'] = service_type
    __args__['transitRouterAttachmentId'] = transit_router_attachment_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cen/getChildInstanceRouteEntryToAttachments:getChildInstanceRouteEntryToAttachments', __args__, opts=opts, typ=GetChildInstanceRouteEntryToAttachmentsResult)
    return __ret__.apply(lambda __response__: GetChildInstanceRouteEntryToAttachmentsResult(
        attachments=pulumi.get(__response__, 'attachments'),
        cen_id=pulumi.get(__response__, 'cen_id'),
        child_instance_route_table_id=pulumi.get(__response__, 'child_instance_route_table_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        service_type=pulumi.get(__response__, 'service_type'),
        transit_router_attachment_id=pulumi.get(__response__, 'transit_router_attachment_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IpamIpamPoolCidrArgs', 'IpamIpamPoolCidr']

@pulumi.input_type
class IpamIpamPoolCidrArgs:
    def __init__(__self__, *,
                 cidr: pulumi.Input[str],
                 ipam_pool_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a IpamIpamPoolCidr resource.
        :param pulumi.Input[str] cidr: The CIDR address segment to be preset.
               
               > **NOTE:**  currently, only IPv4 address segments are supported.
        :param pulumi.Input[str] ipam_pool_id: The ID of the IPAM pool instance.
        """
        pulumi.set(__self__, "cidr", cidr)
        pulumi.set(__self__, "ipam_pool_id", ipam_pool_id)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Input[str]:
        """
        The CIDR address segment to be preset.

        > **NOTE:**  currently, only IPv4 address segments are supported.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: pulumi.Input[str]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter(name="ipamPoolId")
    def ipam_pool_id(self) -> pulumi.Input[str]:
        """
        The ID of the IPAM pool instance.
        """
        return pulumi.get(self, "ipam_pool_id")

    @ipam_pool_id.setter
    def ipam_pool_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "ipam_pool_id", value)


@pulumi.input_type
class _IpamIpamPoolCidrState:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[str]] = None,
                 ipam_pool_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IpamIpamPoolCidr resources.
        :param pulumi.Input[str] cidr: The CIDR address segment to be preset.
               
               > **NOTE:**  currently, only IPv4 address segments are supported.
        :param pulumi.Input[str] ipam_pool_id: The ID of the IPAM pool instance.
        :param pulumi.Input[str] status: The status of the resource
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if ipam_pool_id is not None:
            pulumi.set(__self__, "ipam_pool_id", ipam_pool_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The CIDR address segment to be preset.

        > **NOTE:**  currently, only IPv4 address segments are supported.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter(name="ipamPoolId")
    def ipam_pool_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the IPAM pool instance.
        """
        return pulumi.get(self, "ipam_pool_id")

    @ipam_pool_id.setter
    def ipam_pool_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipam_pool_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class IpamIpamPoolCidr(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr: Optional[pulumi.Input[str]] = None,
                 ipam_pool_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Vpc Ipam Ipam Pool Cidr resource.

        Ipam address pool preset CIDR.

        For information about Vpc Ipam Ipam Pool Cidr and how to use it, see [What is Ipam Pool Cidr](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.234.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_ipam = alicloud.vpc.IpamIpam("defaultIpam", operating_region_lists=["cn-hangzhou"])
        default_ipam_pool = alicloud.vpc.IpamIpamPool("defaultIpamPool",
            ipam_scope_id=default_ipam.private_default_scope_id,
            pool_region_id=default_ipam.region_id,
            ip_version="IPv4")
        default = alicloud.vpc.IpamIpamPoolCidr("default",
            cidr="10.0.0.0/8",
            ipam_pool_id=default_ipam_pool.id)
        ```

        ## Import

        Vpc Ipam Ipam Pool Cidr can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/ipamIpamPoolCidr:IpamIpamPoolCidr example <ipam_pool_id>:<cidr>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr: The CIDR address segment to be preset.
               
               > **NOTE:**  currently, only IPv4 address segments are supported.
        :param pulumi.Input[str] ipam_pool_id: The ID of the IPAM pool instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpamIpamPoolCidrArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Vpc Ipam Ipam Pool Cidr resource.

        Ipam address pool preset CIDR.

        For information about Vpc Ipam Ipam Pool Cidr and how to use it, see [What is Ipam Pool Cidr](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.234.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_ipam = alicloud.vpc.IpamIpam("defaultIpam", operating_region_lists=["cn-hangzhou"])
        default_ipam_pool = alicloud.vpc.IpamIpamPool("defaultIpamPool",
            ipam_scope_id=default_ipam.private_default_scope_id,
            pool_region_id=default_ipam.region_id,
            ip_version="IPv4")
        default = alicloud.vpc.IpamIpamPoolCidr("default",
            cidr="10.0.0.0/8",
            ipam_pool_id=default_ipam_pool.id)
        ```

        ## Import

        Vpc Ipam Ipam Pool Cidr can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/ipamIpamPoolCidr:IpamIpamPoolCidr example <ipam_pool_id>:<cidr>
        ```

        :param str resource_name: The name of the resource.
        :param IpamIpamPoolCidrArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpamIpamPoolCidrArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr: Optional[pulumi.Input[str]] = None,
                 ipam_pool_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpamIpamPoolCidrArgs.__new__(IpamIpamPoolCidrArgs)

            if cidr is None and not opts.urn:
                raise TypeError("Missing required property 'cidr'")
            __props__.__dict__["cidr"] = cidr
            if ipam_pool_id is None and not opts.urn:
                raise TypeError("Missing required property 'ipam_pool_id'")
            __props__.__dict__["ipam_pool_id"] = ipam_pool_id
            __props__.__dict__["status"] = None
        super(IpamIpamPoolCidr, __self__).__init__(
            'alicloud:vpc/ipamIpamPoolCidr:IpamIpamPoolCidr',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr: Optional[pulumi.Input[str]] = None,
            ipam_pool_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'IpamIpamPoolCidr':
        """
        Get an existing IpamIpamPoolCidr resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr: The CIDR address segment to be preset.
               
               > **NOTE:**  currently, only IPv4 address segments are supported.
        :param pulumi.Input[str] ipam_pool_id: The ID of the IPAM pool instance.
        :param pulumi.Input[str] status: The status of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpamIpamPoolCidrState.__new__(_IpamIpamPoolCidrState)

        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["ipam_pool_id"] = ipam_pool_id
        __props__.__dict__["status"] = status
        return IpamIpamPoolCidr(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[str]:
        """
        The CIDR address segment to be preset.

        > **NOTE:**  currently, only IPv4 address segments are supported.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter(name="ipamPoolId")
    def ipam_pool_id(self) -> pulumi.Output[str]:
        """
        The ID of the IPAM pool instance.
        """
        return pulumi.get(self, "ipam_pool_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

